netapp_ontap.models.consistency_group_provisioning_options API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_provisioning_options`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupProvisioningOptionsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupProvisioningOptions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: str POST PATCH`

    Operation to perform

    Valid choices:

    - create
    - add
    - remove
    - promote
    - demote
  `name: str POST PATCH`

    New name for consistency group. Required to resolve naming collisions.

  `snapshot_autodelete_enabled: Dict POST PATCH`

    Enable snapshot autodelete on a storage unit.

  `snapshot_reserve_percent: Dict POST PATCH`

    The space that has been set aside as a reserve for storage unit snapshot usage, in percent.

  `storage_service: ConsistencyGroupConsistencyGroupsProvisioningOptionsStorageService POST PATCH`

    Determines the placement of any storage object created during this operation.

  `verify_tags: List[str] POST PATCH`

    Resource tags to confirm before an update.

    Example: ["team:csi","environment:test"]